function onSensorTypeSelect(evt)
{
	const sensorType = document.querySelector("select[name='sensorType']").value;

	if (sensorType == 'tmp') {
		document.querySelector("input[name='threshold']").min = -40;
		document.querySelector("input[name='threshold']").max = 80;
	} else if (sensorType == 'hdt') {
		document.querySelector("input[name='threshold']").min = 0;
		document.querySelector("input[name='threshold']").max = 100;
	}
}

function customSubmit(evt)
{
	evt.preventDefault()
	console.log(evt)

	const alertForm = document.querySelector('#alert')
	const postParams = new URLSearchParams(new FormData(alertForm))

	const reqParams = {method: "POST", body: postParams}

	for (const errorField of document.querySelectorAll('#alert .error')) {
		errorField.classList.remove("error");
	}

	fetch('/setAlert.cnq', reqParams)
	.then(response => {
		if (!response.ok) {
			throw new Error('Network response was not ok');
		}

		return response.json();
	})
	.then(data => {
		document.querySelector('#alertarea').textContent = ''
		document.querySelector('#alertarea').classList.remove('vs') //remove visibility

		if (data && data["status"] == "ok") {
			//redirect
			window.location.href = "/alerts.cnq";
		}
		else {
			document.querySelector('#alertarea').textContent = 'Save failed.';
			document.querySelector('#alertarea').classList.add('vs');

			let failcauses = data["failcause"];

			for (const failcause of failcauses) {
				const inputElem = document.querySelector('#' + failcause);
				if (inputElem) {
					inputElem.classList.add("error")
				}
			}
		}

		console.log(data)
	})
	.catch(error => {
		console.error('Could not save data:', error);

		document.querySelector('#alertarea').textContent = 'Could not save data to server...'
		document.querySelector('#alertarea').classList.add('vs')
	});
}


function initAlertEditForm() {
	const alertForm = document.querySelector('#alert')
	alertForm.addEventListener('submit', customSubmit);

	let urlHash = window.location.hash.substr(1);

	if (urlHash) {
		fetch('/getAlerts.cnq?'+urlHash)
		.then(response => {
			if (!response.ok) {
				throw new Error('Network response was not ok');
			}

			return response.json();
		})
		.then(data => {
			document.querySelector('#alertarea').textContent = ''
			document.querySelector('#alertarea').classList.remove('vs') //remove visibility

			buildAlerts(data);
		})
		.catch(error => {
			console.error('Could not fetch data:', error);

			document.querySelector('#alertarea').textContent = 'Could not load data from server...'
			document.querySelector('#alertarea').classList.add('vs')
		});
	} else {
		document.querySelector('#alertarea').textContent = '';
		document.querySelector('#alertarea').classList.remove('vs'); //remove visibility

		const fieldsets = alertForm.querySelectorAll('fieldset')
		for (let fieldset of fieldsets) {
			fieldset.disabled = false
		}
	}
}



function buildAlerts(data)
{
	console.log(data)
	if (!data || Array.isArray(data))
	{
		document.querySelector('#alertarea').textContent = 'Alert does not exist...'
		document.querySelector('#alertarea').classList.add('vs')
		return
	}

	const alertForm = document.querySelector('#alert')
	alertForm.querySelector('#alert_id').value = data['alert_id']
	alertForm.querySelector('#alert_name').value = data['alert_name']
	alertForm.querySelector('#alert_trigger').value = data['alert_trigger']
	alertForm.querySelector('#rearm_trigger').value = data['rearm_trigger']
	alertForm.querySelector('#is_active').value = data['is_active'] ? "1" : "0"

	alertForm.querySelector('#email_subject').value = data['subject']
	alertForm.querySelector('#email_msg').value = data['message']

	const emails = JSON.parse(data['email_addresses'])
	if (emails && emails.length > 0) {
		//TODO show all email addresses
		alertForm.querySelector('#email_address').value = emails[0]
	}

	const fieldsets = alertForm.querySelectorAll('fieldset')
	for (let fieldset of fieldsets) {
		fieldset.disabled = false
	}

	parseAlertConfig(document.querySelector("#alert_trigger").value);
}

function updateSensorList() {
	const sensors = document.querySelector("select[id='sensorId']");
	const keys = Object.keys(localStorage);
  let i=0;

  for (let key of keys)
  {
    if (key.startsWith('sensor-config-'))
    {
      let sensorConfigItem = localStorage.getItem(key)
      if (!sensorConfigItem)
        continue;

      sensorConfigItem = JSON.parse(sensorConfigItem)

      let hidden = sensorConfigItem['hidden'] || false

			if (hidden)
				continue;

      //addSensorWidget(sensorConfigItem['sensorId'], sensorConfigItem['sensorType'], sensorConfigItem['label'], hidden)
			let option = document.createElement( 'option' );
			option.value = sensorConfigItem['sensorId'];
	    option.text = sensorConfigItem['label'];
	    sensors.add( option );
      i++
    }
  }
}

function updateAlertTrigger() {

	const sensorId = document.querySelector("select[id='sensorId']").value;
	const sensorType = document.querySelector("select[name='sensorType']").value;
	const operand = document.querySelector("select[name='operand']").value;
	const threshold = document.querySelector("input[name='threshold']").value;

	if (sensorId && sensorType && operand && threshold) {
		const alertTrigger = document.querySelector("#alert_trigger");
		const reArmTrigger = document.querySelector("#rearm_trigger");

		let newTrigger = 'sensors[' + sensorId + '].' + sensorType + ' ' + operand + ' ' + threshold;
		alertTrigger.value = newTrigger;


		let reArmThreshold = parseFloat(threshold);
		let factor = 1;
		if (operand == '>' || operand == '>=') {
			factor = -1;
		}

		let reverseOp = '';
		switch (operand) {
			case '>':
				reverseOp = '<=';
				break;
			case '>=':
				reverseOp = '<';
				break;
			case '<':
				reverseOp = '>=';
				break;
			case '<=':
				reverseOp = '>';
				break;
		}

		if (sensorType == 'tmp')
			reArmThreshold += 0.1 * factor; //for temp
		else if (sensorType == 'hdt')
			reArmThreshold += 1.0 * factor; //for rH

		reArmThreshold = +reArmThreshold.toFixed(2);

		reArmTrigger.value = 'sensors[' + sensorId + '].' + sensorType + ' ' + reverseOp + ' ' + reArmThreshold;
	}
}

function onRuleModeChange(evt) {
	evt.preventDefault();
	selRuleMode(evt.target);
}

function selRuleMode(ruleModelEl) {
	document.querySelectorAll(".ruleSel a").forEach(
		function(aEl) { aEl.classList.remove('selected');}
	);

	ruleModelEl.classList.add("selected");

	if (ruleModelEl.id == 'easyRule') {
		document.querySelector("#expertRuleContainer").style.display='none';
		document.querySelector("#easyRuleContainer").style.display='block';

    document.querySelectorAll('#easyRuleContainer select, #easyRuleContainer input').forEach(
      function(input) {
        input.disabled=false
      }
    );
	}
	else {
		document.querySelector("#easyRuleContainer").style.display='none';
		document.querySelector("#expertRuleContainer").style.display='block';

    document.querySelectorAll('#easyRuleContainer select, #easyRuleContainer input').forEach(
      function(input) {
        input.disabled=true
      }
    );
	}

}


function parseAlertConfig(alertConfigStr) {
  const re = /sensors\[(\d+)\]\.(tmp|hdt)\s+(>|<|<=|>=)\s*([[\d\.]+)/;
  let matches = alertConfigStr.match(re);

  if (matches) {
    let sensorId = matches[1];
    let sensorType = matches[2];
    let op = matches[3];
    let threshold = matches[4];

    document.querySelector("select[id='sensorId']").value = sensorId;
    document.querySelector("select[name='sensorType']").value = sensorType;
    document.querySelector("select[name='operand']").value = op;
    document.querySelector("input[name='threshold']").value = threshold;

    selRuleMode(document.querySelector("#easyRule"));
  } else if (!alertConfigStr) {
    selRuleMode(document.querySelector("#easyRule"));
  } else {
    selRuleMode(document.querySelector("#expertRule"));
  }
}
