const translations = {
  "en": {
    "sensor-id": "Sensor ID",
    "signal-strength": "Signal Strength",
    "batt-voltage": "Battery Voltage",
    "fw-rev": "Firmware Revision",
    "hw-rev": "Hardware Revision",
    "build-date": "Build Date",
    "max-tx-power": "Max. Transmission Power",
    "tx-interval": "Transmission Interval",
		"local-gw-ip": "Local Gateway IP",
		"gw-cloud-status-label": "Gateway <-> Cloud",
    "gw-cloud-status-offline": 'Gateway {0} is not connected to Cloud.',
		"connection-unknown": "Unknown",
		"connection-offline": "Not connected",
		"connection-online": "Connected",
    "connection-label": "Connection",
    "start-date-label": "Start date",
    "end-date-label": "End date",
    "sensor-descriptor": "Label",
    "save": "Save",
    "show-chart-label": "Show Chart",
    "seconds": "seconds"
  },
  "de": {
		"sensor-id": "Sensor ID",
    "signal-strength": "Signalstärke",
    "batt-voltage": "Batteriespannung",
    "fw-rev": "Firmware Revision",
    "hw-rev": "Hardware Revision",
    "build-date": "Herstellungsdatum",
    "max-tx-power": "max. Sendeleistung",
    "tx-interval": "Sende-Intervall",
		"local-gw-ip": "Lokale Gateway IP",
		"gw-cloud-status-label": "Gateway <-> Cloud",
    "gw-cloud-status-offline": 'Gateway {0} ist nicht mit Cloud verbunden.',
		"connection-unknown": "Unbekannt",
		"connection-offline": "Nicht verbunden",
		"connection-online": "Verbunden",
    "connection-label": "Verbindung",
    "start-date-label": "Von",
    "end-date-label": "Bis",
    "sensor-descriptor": "Bezeichnung",
    "save": "Speichern",
    "show-chart-label": "Diagramm anzeigen",
    "seconds": "Sekunden"
  },
};


var localeObj = null;

String.prototype.format = function () {
  var args = arguments;
  return this.replace(/{([0-9]+)}/g, function (match, index) {
    return typeof args[index] == 'undefined' ? match : args[index];
  });
};

function initTranslations(translationLocale) {
  localeObj = translationLocale;
  document.addEventListener("DOMContentLoaded", () => {
    document.querySelectorAll("[data-i18n-key]").forEach(translateElement);
  });
}

function translateKey(key, param) {
  let translation = '';
	if (localeObj.language in translations && key in translations[localeObj.language]) {
		translation = translations[localeObj.language][key];
	}
	else {
		translation = translations['de'][key];
	}

  if (param !== undefined) {
    return translation.format(param);
  } else {
    return translation;
  }
}

function translateElement(element) {
  if (element.tagName == 'INPUT' && (element.type == 'submit' || element.type == 'button'))
    element.value = translateKey(element.getAttribute("data-i18n-key"));
  else
    element.textContent = translateKey(element.getAttribute("data-i18n-key"));
}
